@@ -48,7 +48,7 @@ Shortcuts :
 • Ctrl-W : Close file
 • Ctrl-I : Show file info
 • Ctrl-C : Copy
-• Ctrl-C : Cut
+• Ctrl-X : Cut
 • Ctrl-V : Paste
 • Ctrl-Z : Undo
 • Ctrl-Y : Redo
@@ -151,6 +151,10 @@ Roadmap :
 ◦ Fix back to begin search when there is 2 results only
 ◦ Fix order of recent files
 
+•Version 3.0.10 :
+◦ Fix help text (Wrong shortcut for cut)
+◦ Fix welcome screen new button bug
+
 •Version 3.3.0 :
 ◦ Plugins
 ◦ Snippet
