@@ -103,6 +103,7 @@ class Window(hildon.Window):
     self.show_all()
     self.saved=True
 
+    print filepath
     if filepath!=None:
       self.set_title(os.path.basename(filepath))
       self.open_file(filepath)
@@ -324,6 +325,7 @@ class Window(hildon.Window):
       manager = gtk.recent_manager_get_default()
       manager.add_item('file://'+filepath)
     except StandardError,e:
+      print e
       note = osso.SystemNote(self._parent.context)
       result = note.system_note_dialog('An error occurs opening file :\n'+str(e))
   
